# CHANGELOG

## Version 0.1.0 12.01.2024
Repository creation

## Version 0.1.1 12.03.2024
Minor changes

## Version 0.1.2 12.03.2024
Minor changes

## Version 0.1.3 12.03.2024
Minor changes

## Version 0.1.4 02.13.2025
Dependencies issues
